@@ -1,10 +1,8 @@
 package HTTP::Engine::ResponseFinalizer;
 use strict;
 use warnings;
-use CGI::Simple::Cookie ();
 use Scalar::Util        ();
 use Carp                ();
-use File::stat          ();
 
 sub finalize {
     my ($class, $req, $res) = @_;
@@ -17,10 +15,11 @@ sub finalize {
     if ($res->body) {
         # get the length from a filehandle
         if ((Scalar::Util::blessed($res->body) && $res->body->can('read')) || (ref($res->body) eq 'GLOB')) {
-            if (my $stat = eval { File::stat::stat $res->body }) {
+            HTTP::Engine::Util::require_once('File/stat.pm');
+            if (my $stat = eval { File::stat::stat($res->body) }) {
                 $res->content_length($stat->size);
             } else {
-                die 'Serving filehandle without a content-length';
+                die "Serving filehandle without a content-length($@)";
             }
         } else {
             $res->content_length(bytes::length($res->body));
@@ -51,22 +50,28 @@ sub finalize {
 sub _finalize_cookies  {
     my ($class, $res) = @_;
 
-    for my $name (keys %{ $res->cookies }) {
-        my $val = $res->cookies->{$name};
-        my $cookie = (
-            Scalar::Util::blessed($val)
-            ? $val
-            : CGI::Simple::Cookie->new(
-                -name    => $name,
-                -value   => $val->{value},
-                -expires => $val->{expires},
-                -domain  => $val->{domain},
-                -path    => $val->{path},
-                -secure  => ($val->{secure} || 0)
-            )
-        );
+    my $cookies = $res->cookies;
+    my @keys = keys %$cookies;
+    if (@keys) {
+        HTTP::Engine::Util::require_once('CGI/Simple/Cookie.pm');
 
-        $res->headers->push_header('Set-Cookie' => $cookie->as_string);
+        for my $name (@keys) {
+            my $val = $cookies->{$name};
+            my $cookie = (
+                Scalar::Util::blessed($val)
+                ? $val
+                : CGI::Simple::Cookie->new(
+                    -name    => $name,
+                    -value   => $val->{value},
+                    -expires => $val->{expires},
+                    -domain  => $val->{domain},
+                    -path    => $val->{path},
+                    -secure  => ($val->{secure} || 0)
+                )
+            );
+
+            $res->headers->push_header('Set-Cookie' => $cookie->as_string);
+        }
     }
 }
 
